
# Clios

![Test Status](https://github.com/prajeeshag/clios/actions/workflows/test.yml/badge.svg)
![Doc Status](https://github.com/prajeeshag/clios/actions/workflows/build-docs.yml/badge.svg)
![PyPI - Version](https://img.shields.io/pypi/v/clios)
[![codecov](https://codecov.io/gh/prajeeshag/clios/graph/badge.svg?token=UNNUW30IQL)](https://codecov.io/gh/prajeeshag/clios)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/clios)
---

**Documentation**: [https://prajeesh-ag.com/clios](https://prajeesh-ag.com/clios)

___

**Clios** is a Python library designed to create chainable command-line operators with ease. Inspired by **Climate Data Operators** ([**CDO**](https://code.mpimet.mpg.de/projects/cdo)), it makes it simple to build CDO-like application in Python. Powered by **Pydantic**!

## Installation
<!--termynal-->
```
$ pip install clios
```
